"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    activation_key: str,
    agent_name: str = None,
    tags: List = None,
    vpc_endpoint_id: str = None,
    subnet_arns: List = None,
    security_group_arns: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Activates an AWS DataSync agent that you have deployed on your host. The activation process associates your agent with your account. In the activation process, you specify information such as the AWS Region that you want to activate the agent in. You activate the agent in the AWS Region where your target locations (in Amazon S3 or Amazon EFS) reside. Your tasks are created in this AWS Region. You can activate the agent in a VPC (virtual private cloud) or provide the agent access to a VPC endpoint so you can run tasks without going over the public internet. You can use an agent for more than one location. If a task uses multiple agents, all of them need to have status AVAILABLE for the task to run. If you use multiple agents for a source location, the status of all the agents must be AVAILABLE for the task to run.  Agents are automatically updated by AWS on a regular basis, using a mechanism that ensures minimal interruption to your tasks.

    Args:
        activation_key(str): Your agent activation key. You can get the activation key either by sending an HTTP GET request with redirects that enable you to get the agent IP address (port 80). Alternatively, you can get it from the AWS DataSync console. The redirect URL returned in the response provides you the activation key for your agent in the query string parameter activationKey. It might also include other activation-related parameters; however, these are merely defaults. The arguments you pass to this API call determine the actual configuration of your agent. For more information, see Activating an Agent in the AWS DataSync User Guide. .
        agent_name(str, optional): The name you configured for your agent. This value is a text reference that is used to identify the agent in the console. Defaults to None.
        tags(List, optional): The key-value pair that represents the tag that you want to associate with the agent. The value can be an empty string. This value helps you manage, filter, and search for your agents.  Valid characters for key and value are letters, spaces, and numbers representable in UTF-8 format, and the following special characters: + - = . _ : / @.  . Defaults to None.
        vpc_endpoint_id(str, optional): The ID of the VPC (virtual private cloud) endpoint that the agent has access to. This is the client-side VPC endpoint, also called a PrivateLink. If you don't have a PrivateLink VPC endpoint, see Creating a VPC Endpoint Service Configuration in the Amazon VPC User Guide. VPC endpoint ID looks like this: vpce-01234d5aff67890e1. Defaults to None.
        subnet_arns(List, optional): The Amazon Resource Names (ARNs) of the subnets in which DataSync will create elastic network interfaces for each data transfer task. The agent that runs a task must be private. When you start a task that is associated with an agent created in a VPC, or one that has access to an IP address in a VPC, then the task is also private. In this case, DataSync creates four network interfaces for each task in your subnet. For a data transfer to work, the agent must be able to route to all these four network interfaces. Defaults to None.
        security_group_arns(List, optional): The ARNs of the security groups used to protect your data transfer task subnets. See SecurityGroupArns. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.datasync.agent.create(ctx, activation_key=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.datasync.agent.create activation_key=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="datasync",
        operation="create_agent",
        op_kwargs={
            "ActivationKey": activation_key,
            "AgentName": agent_name,
            "Tags": tags,
            "VpcEndpointId": vpc_endpoint_id,
            "SubnetArns": subnet_arns,
            "SecurityGroupArns": security_group_arns,
        },
    )


async def delete(hub, ctx, agent_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an agent. To specify which agent to delete, use the Amazon Resource Name (ARN) of the agent in your request. The operation disassociates the agent from your AWS account. However, it doesn't delete the agent virtual machine (VM) from your on-premises environment.

    Args:
        agent_arn(str): The Amazon Resource Name (ARN) of the agent to delete. Use the ListAgents operation to return a list of agents for your account and AWS Region.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.datasync.agent.delete(ctx, agent_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.datasync.agent.delete agent_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="datasync",
        operation="delete_agent",
        op_kwargs={"AgentArn": agent_arn},
    )


async def describe(hub, ctx, agent_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns metadata such as the name, the network interfaces, and the status (that is, whether the agent is running or not) for an agent. To specify which agent to describe, use the Amazon Resource Name (ARN) of the agent in your request.

    Args:
        agent_arn(str): The Amazon Resource Name (ARN) of the agent to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.datasync.agent.describe(ctx, agent_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.datasync.agent.describe agent_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="datasync",
        operation="describe_agent",
        op_kwargs={"AgentArn": agent_arn},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of agents owned by an AWS account in the AWS Region specified in the request. The returned list is ordered by agent Amazon Resource Name (ARN). By default, this operation returns a maximum of 100 agents. This operation supports pagination that enables you to optionally reduce the number of agents returned in a response. If you have more agents than are returned in a response (that is, the response returns only a truncated list of your agents), the response contains a marker that you can specify in your next request to fetch the next page of agents.

    Args:
        max_results(int, optional): The maximum number of agents to list. Defaults to None.
        next_token(str, optional): An opaque string that indicates the position at which to begin the next list of agents. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.datasync.agent.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.datasync.agent.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="datasync",
        operation="list_agents",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )


async def update(hub, ctx, agent_arn: str, name: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Updates the name of an agent.

    Args:
        agent_arn(str): The Amazon Resource Name (ARN) of the agent to update.
        name(str, optional): The name that you want to use to configure the agent. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.datasync.agent.update(ctx, agent_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.datasync.agent.update agent_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="datasync",
        operation="update_agent",
        op_kwargs={"AgentArn": agent_arn, "Name": name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def associate(
    hub, ctx, instance_id: str, lex_bot: Dict = None, lex_v2_bot: Dict = None
) -> None:
    r"""
    **Autogenerated function**

    This API is in preview release for Amazon Connect and is subject to change. Allows the specified Amazon Connect instance to access the specified Amazon Lex or Amazon Lex V2 bot.

    Args:
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.
        lex_bot(Dict, optional): Configuration information of an Amazon Lex bot. Defaults to None.
        lex_v2_bot(Dict, optional): The Amazon Lex V2 bot to associate with the instance. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.bot.associate(ctx, instance_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.bot.associate instance_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="associate_bot",
        op_kwargs={
            "InstanceId": instance_id,
            "LexBot": lex_bot,
            "LexV2Bot": lex_v2_bot,
        },
    )


async def disassociate(
    hub, ctx, instance_id: str, lex_bot: Dict = None, lex_v2_bot: Dict = None
) -> None:
    r"""
    **Autogenerated function**

    This API is in preview release for Amazon Connect and is subject to change. Revokes authorization from the specified instance to access the specified Amazon Lex or Amazon Lex V2 bot.

    Args:
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.
        lex_bot(Dict, optional): Configuration information of an Amazon Lex bot. Defaults to None.
        lex_v2_bot(Dict, optional): The Amazon Lex V2 bot to disassociate from the instance. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.bot.disassociate(ctx, instance_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.bot.disassociate instance_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="disassociate_bot",
        op_kwargs={
            "InstanceId": instance_id,
            "LexBot": lex_bot,
            "LexV2Bot": lex_v2_bot,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def resend(
    hub, ctx, certificate_arn: str, domain: str, validation_domain: str
) -> None:
    r"""
    **Autogenerated function**

    Resends the email that requests domain ownership validation. The domain owner or an authorized representative must approve the ACM certificate before it can be issued. The certificate can be approved by clicking a link in the mail to navigate to the Amazon certificate approval website and then clicking I Approve. However, the validation email can be blocked by spam filters. Therefore, if you do not receive the original mail, you can request that the mail be resent within 72 hours of requesting the ACM certificate. If more than 72 hours have elapsed since your original request or since your last attempt to resend validation mail, you must request a new certificate. For more information about setting up your contact email addresses, see Configure Email for your Domain.

    Args:
        certificate_arn(str): String that contains the ARN of the requested certificate. The certificate ARN is generated and returned by the RequestCertificate action as soon as the request is made. By default, using this parameter causes email to be sent to all top-level domains you specified in the certificate request. The ARN must be of the form:   arn:aws:acm:us-east-1:123456789012:certificate/12345678-1234-1234-1234-123456789012 .
        domain(str): The fully qualified domain name (FQDN) of the certificate that needs to be validated.
        validation_domain(str): The base validation domain that will act as the suffix of the email addresses that are used to send the emails. This must be the same as the Domain value or a superdomain of the Domain value. For example, if you requested a certificate for site.subdomain.example.com and specify a ValidationDomain of subdomain.example.com, ACM sends email to the domain registrant, technical contact, and administrative contact in WHOIS and the following five addresses:   admin@subdomain.example.com   administrator@subdomain.example.com   hostmaster@subdomain.example.com   postmaster@subdomain.example.com   webmaster@subdomain.example.com  .
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.acm.validation_email.resend(
                ctx, certificate_arn=value, domain=value, validation_domain=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.acm.validation_email.resend certificate_arn=value, domain=value, validation_domain=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="acm",
        operation="resend_validation_email",
        op_kwargs={
            "CertificateArn": certificate_arn,
            "Domain": domain,
            "ValidationDomain": validation_domain,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub, ctx, certificate_signing_request: str, set_as_active: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an X.509 certificate using the specified certificate signing request.  Note: The CSR must include a public key that is either an RSA key with a length of at least 2048 bits or an ECC key from NIST P-256 or NIST P-384 curves.   Note: Reusing the same certificate signing request (CSR) results in a distinct certificate. You can create multiple certificates in a batch by creating a directory, copying multiple .csr files into that directory, and then specifying that directory on the command line. The following commands show how to create a batch of certificates given a batch of CSRs. Assuming a set of CSRs are located inside of the directory my-csr-directory: On Linux and OS X, the command is: $ ls my-csr-directory/ | xargs -I {} aws iot create-certificate-from-csr --certificate-signing-request file://my-csr-directory/{} This command lists all of the CSRs in my-csr-directory and pipes each CSR file name to the aws iot create-certificate-from-csr AWS CLI command to create a certificate for the corresponding CSR. The aws iot create-certificate-from-csr part of the command can also be run in parallel to speed up the certificate creation process: $ ls my-csr-directory/ | xargs -P 10 -I {} aws iot create-certificate-from-csr --certificate-signing-request file://my-csr-directory/{} On Windows PowerShell, the command to create certificates for all CSRs in my-csr-directory is: > ls -Name my-csr-directory | %{aws iot create-certificate-from-csr --certificate-signing-request file://my-csr-directory/$_} On a Windows command prompt, the command to create certificates for all CSRs in my-csr-directory is: > forfiles /p my-csr-directory /c "cmd /c aws iot create-certificate-from-csr --certificate-signing-request file://@path"

    Args:
        certificate_signing_request(str): The certificate signing request (CSR).
        set_as_active(bool, optional): Specifies whether the certificate is active. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.certificate.from_csr.create(
                ctx, certificate_signing_request=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.certificate.from_csr.create certificate_signing_request=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="create_certificate_from_csr",
        op_kwargs={
            "certificateSigningRequest": certificate_signing_request,
            "setAsActive": set_as_active,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(hub, ctx, deployment_ids: List) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about one or more deployments. The maximum number of deployments that can be returned is 25.

    Args:
        deployment_ids(List):  A list of deployment IDs, separated by spaces. The maximum number of deployment IDs you can specify is 25.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codedeploy.get.deployment.init.batch(ctx, deployment_ids=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codedeploy.get.deployment.init.batch deployment_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codedeploy",
        operation="batch_get_deployments",
        op_kwargs={"deploymentIds": deployment_ids},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, resource_arn: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the resource-based policy attached to a private CA. Deletion will remove any access that the policy has granted. If there is no policy attached to the private CA, this action will return successful. If you delete a policy that was applied through AWS Resource Access Manager (RAM), the CA will be removed from all shares in which it was included.  The AWS Certificate Manager Service Linked Role that the policy supports is not affected when you delete the policy.  The current policy can be shown with GetPolicy and updated with PutPolicy.  About Policies    A policy grants access on a private CA to an AWS customer account, to AWS Organizations, or to an AWS Organizations unit. Policies are under the control of a CA administrator. For more information, see Using a Resource Based Policy with ACM Private CA.   A policy permits a user of AWS Certificate Manager (ACM) to issue ACM certificates signed by a CA in another account.   For ACM to manage automatic renewal of these certificates, the ACM user must configure a Service Linked Role (SLR). The SLR allows the ACM service to assume the identity of the user, subject to confirmation against the ACM Private CA policy. For more information, see Using a Service Linked Role with ACM.   Updates made in AWS Resource Manager (RAM) are reflected in policies. For more information, see Attach a Policy for Cross-Account Access.

    Args:
        resource_arn(str): The Amazon Resource Number (ARN) of the private CA that will have its policy deleted. You can find the CA's ARN by calling the ListCertificateAuthorities action. The ARN value must have the form arn:aws:acm-pca:region:account:certificate-authority/01234567-89ab-cdef-0123-0123456789ab. .
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.acm_pca.policy.delete(ctx, resource_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.acm_pca.policy.delete resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="acm-pca",
        operation="delete_policy",
        op_kwargs={"ResourceArn": resource_arn},
    )


async def get(hub, ctx, resource_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the resource-based policy attached to a private CA. If either the private CA resource or the policy cannot be found, this action returns a ResourceNotFoundException.  The policy can be attached or updated with PutPolicy and removed with DeletePolicy.  About Policies    A policy grants access on a private CA to an AWS customer account, to AWS Organizations, or to an AWS Organizations unit. Policies are under the control of a CA administrator. For more information, see Using a Resource Based Policy with ACM Private CA.   A policy permits a user of AWS Certificate Manager (ACM) to issue ACM certificates signed by a CA in another account.   For ACM to manage automatic renewal of these certificates, the ACM user must configure a Service Linked Role (SLR). The SLR allows the ACM service to assume the identity of the user, subject to confirmation against the ACM Private CA policy. For more information, see Using a Service Linked Role with ACM.   Updates made in AWS Resource Manager (RAM) are reflected in policies. For more information, see Attach a Policy for Cross-Account Access.

    Args:
        resource_arn(str): The Amazon Resource Number (ARN) of the private CA that will have its policy retrieved. You can find the CA's ARN by calling the ListCertificateAuthorities action. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.acm_pca.policy.get(ctx, resource_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.acm_pca.policy.get resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="acm-pca",
        operation="get_policy",
        op_kwargs={"ResourceArn": resource_arn},
    )


async def put(hub, ctx, resource_arn: str, policy: str) -> None:
    r"""
    **Autogenerated function**

    Attaches a resource-based policy to a private CA.  A policy can also be applied by sharing a private CA through AWS Resource Access Manager (RAM). For more information, see Attach a Policy for Cross-Account Access. The policy can be displayed with GetPolicy and removed with DeletePolicy.  About Policies    A policy grants access on a private CA to an AWS customer account, to AWS Organizations, or to an AWS Organizations unit. Policies are under the control of a CA administrator. For more information, see Using a Resource Based Policy with ACM Private CA.   A policy permits a user of AWS Certificate Manager (ACM) to issue ACM certificates signed by a CA in another account.   For ACM to manage automatic renewal of these certificates, the ACM user must configure a Service Linked Role (SLR). The SLR allows the ACM service to assume the identity of the user, subject to confirmation against the ACM Private CA policy. For more information, see Using a Service Linked Role with ACM.   Updates made in AWS Resource Manager (RAM) are reflected in policies. For more information, see Attach a Policy for Cross-Account Access.

    Args:
        resource_arn(str): The Amazon Resource Number (ARN) of the private CA to associate with the policy. The ARN of the CA can be found by calling the ListCertificateAuthorities action. .
        policy(str): The path and file name of a JSON-formatted IAM policy to attach to the specified private CA resource. If this policy does not contain all required statements or if it includes any statement that is not allowed, the PutPolicy action returns an InvalidPolicyException. For information about IAM policy and statement structure, see Overview of JSON Policies.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.acm_pca.policy.put(ctx, resource_arn=value, policy=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.acm_pca.policy.put resource_arn=value, policy=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="acm-pca",
        operation="put_policy",
        op_kwargs={"ResourceArn": resource_arn, "Policy": policy},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__sub_alias__ = ["lambda_", "lambda"]


async def invoke(
    hub,
    ctx,
    function_name: str,
    invocation_type: str = None,
    log_type: str = None,
    client_context: str = None,
    payload: bytes = None,
    qualifier: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Invokes a Lambda function. You can invoke a function synchronously (and wait for the response), or asynchronously. To invoke a function asynchronously, set InvocationType to Event. For synchronous invocation, details about the function response, including errors, are included in the response body and headers. For either invocation type, you can find more information in the execution log and trace. When an error occurs, your function may be invoked multiple times. Retry behavior varies by error type, client, event source, and invocation type. For example, if you invoke a function asynchronously and it returns an error, Lambda executes the function up to two more times. For more information, see Retry Behavior. For asynchronous invocation, Lambda adds events to a queue before sending them to your function. If your function does not have enough capacity to keep up with the queue, events may be lost. Occasionally, your function may receive the same event multiple times, even if no error occurs. To retain events that were not processed, configure your function with a dead-letter queue. The status code in the API response doesn't reflect function errors. Error codes are reserved for errors that prevent your function from executing, such as permissions errors, limit errors, or issues with your function's code and configuration. For example, Lambda returns TooManyRequestsException if executing the function would cause you to exceed a concurrency limit at either the account level (ConcurrentInvocationLimitExceeded) or function level (ReservedFunctionConcurrentInvocationLimitExceeded). For functions with a long timeout, your client might be disconnected during synchronous invocation while it waits for a response. Configure your HTTP client, SDK, firewall, proxy, or operating system to allow for long connections with timeout or keep-alive settings. This operation requires permission for the lambda:InvokeFunction action.

    Args:
        function_name(str): The name of the Lambda function, version, or alias.  Name formats     Function name - my-function (name-only), my-function:v1 (with alias).    Function ARN - arn:aws:lambda:us-west-2:123456789012:function:my-function.    Partial ARN - 123456789012:function:my-function.   You can append a version number or alias to any of the formats. The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
        invocation_type(str, optional): Choose from the following options.    RequestResponse (default) - Invoke the function synchronously. Keep the connection open until the function returns a response or times out. The API response includes the function response and additional data.    Event - Invoke the function asynchronously. Send events that fail multiple times to the function's dead-letter queue (if it's configured). The API response only includes a status code.    DryRun - Validate parameter values and verify that the user or role has permission to invoke the function.  . Defaults to None.
        log_type(str, optional): Set to Tail to include the execution log in the response. Defaults to None.
        client_context(str, optional): Up to 3583 bytes of base64-encoded data about the invoking client to pass to the function in the context object. Defaults to None.
        payload(bytes, optional): The JSON that you want to provide to your Lambda function as input. Defaults to None.
        qualifier(str, optional): Specify a version or alias to invoke a published version of the function. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lambda_.init.invoke(ctx, function_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lambda_.init.invoke function_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lambda",
        operation="invoke",
        op_kwargs={
            "FunctionName": function_name,
            "InvocationType": invocation_type,
            "LogType": log_type,
            "ClientContext": client_context,
            "Payload": payload,
            "Qualifier": qualifier,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    time_period: Dict,
    metric: str,
    granularity: str,
    filter_: Dict = None,
    prediction_interval_level: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a forecast for how much Amazon Web Services predicts that you will spend over the forecast time period that you select, based on your past costs.

    Args:
        time_period(Dict): The period of time that you want the forecast to cover. The start date must be equal to or no later than the current date to avoid a validation error.
        metric(str): Which metric Cost Explorer uses to create your forecast. For more information about blended and unblended rates, see Why does the "blended" annotation appear on some line items in my bill?.  Valid values for a GetCostForecast call are the following:   AMORTIZED_COST   BLENDED_COST   NET_AMORTIZED_COST   NET_UNBLENDED_COST   UNBLENDED_COST  .
        granularity(str): How granular you want the forecast to be. You can get 3 months of DAILY forecasts or 12 months of MONTHLY forecasts. The GetCostForecast operation supports only DAILY and MONTHLY granularities.
        filter_(Dict, optional): The filters that you want to use to filter your forecast. The GetCostForecast API supports filtering by the following dimensions:    AZ     INSTANCE_TYPE     LINKED_ACCOUNT     LINKED_ACCOUNT_NAME     OPERATION     PURCHASE_TYPE     REGION     SERVICE     USAGE_TYPE     USAGE_TYPE_GROUP     RECORD_TYPE     OPERATING_SYSTEM     TENANCY     SCOPE     PLATFORM     SUBSCRIPTION_ID     LEGAL_ENTITY_NAME     DEPLOYMENT_OPTION     DATABASE_ENGINE     INSTANCE_TYPE_FAMILY     BILLING_ENTITY     RESERVATION_ID     SAVINGS_PLAN_ARN   . Defaults to None.
        prediction_interval_level(int, optional): Cost Explorer always returns the mean forecast as a single point. You can request a prediction interval around the mean by specifying a confidence level. The higher the confidence level, the more confident Cost Explorer is about the actual value falling in the prediction interval. Higher confidence levels result in wider prediction intervals. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ce.cost.forecast.get(
                ctx, time_period=value, metric=value, granularity=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ce.cost.forecast.get time_period=value, metric=value, granularity=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ce",
        operation="get_cost_forecast",
        op_kwargs={
            "TimePeriod": time_period,
            "Metric": metric,
            "Granularity": granularity,
            "Filter": filter_,
            "PredictionIntervalLevel": prediction_interval_level,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, job_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets the properties associated with a PII entities detection job. For example, you can use this operation to get the job status.

    Args:
        job_id(str): The identifier that Amazon Comprehend generated for the job. The operation returns this identifier in its response.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.comprehend.pii_entity.detection_job.describe(ctx, job_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.comprehend.pii_entity.detection_job.describe job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="comprehend",
        operation="describe_pii_entities_detection_job",
        op_kwargs={"JobId": job_id},
    )


async def list_all(
    hub, ctx, filter_: Dict = None, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets a list of the PII entity detection jobs that you have submitted.

    Args:
        filter_(Dict, optional): Filters the jobs that are returned. You can filter jobs on their name, status, or the date and time that they were submitted. You can only set one filter at a time. Defaults to None.
        next_token(str, optional): Identifies the next page of results to return. Defaults to None.
        max_results(int, optional): The maximum number of results to return in each page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.comprehend.pii_entity.detection_job.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.comprehend.pii_entity.detection_job.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="comprehend",
        operation="list_pii_entities_detection_jobs",
        op_kwargs={
            "Filter": filter_,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def start(
    hub,
    ctx,
    input_data_config: Dict,
    output_data_config: Dict,
    mode: str,
    data_access_role_arn: str,
    language_code: str,
    redaction_config: Dict = None,
    job_name: str = None,
    client_request_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Starts an asynchronous PII entity detection job for a collection of documents.

    Args:
        input_data_config(Dict): The input properties for a PII entities detection job.
        output_data_config(Dict): Provides conﬁguration parameters for the output of PII entity detection jobs.
        mode(str): Specifies whether the output provides the locations (offsets) of PII entities or a file in which PII entities are redacted.
        redaction_config(Dict, optional): Provides configuration parameters for PII entity redaction. This parameter is required if you set the Mode parameter to ONLY_REDACTION. In that case, you must provide a RedactionConfig definition that includes the PiiEntityTypes parameter. Defaults to None.
        data_access_role_arn(str): The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM) role that grants Amazon Comprehend read access to your input data.
        job_name(str, optional): The identifier of the job. Defaults to None.
        language_code(str): The language of the input documents.
        client_request_token(str, optional): A unique identifier for the request. If you don't set the client request token, Amazon Comprehend generates one. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.comprehend.pii_entity.detection_job.start(
                ctx,
                input_data_config=value,
                output_data_config=value,
                mode=value,
                data_access_role_arn=value,
                language_code=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.comprehend.pii_entity.detection_job.start input_data_config=value, output_data_config=value, mode=value, data_access_role_arn=value, language_code=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="comprehend",
        operation="start_pii_entities_detection_job",
        op_kwargs={
            "InputDataConfig": input_data_config,
            "OutputDataConfig": output_data_config,
            "Mode": mode,
            "RedactionConfig": redaction_config,
            "DataAccessRoleArn": data_access_role_arn,
            "JobName": job_name,
            "LanguageCode": language_code,
            "ClientRequestToken": client_request_token,
        },
    )


async def stop(hub, ctx, job_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Stops a PII entities detection job in progress.

    Args:
        job_id(str): The identifier of the PII entities detection job to stop.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.comprehend.pii_entity.detection_job.stop(ctx, job_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.comprehend.pii_entity.detection_job.stop job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="comprehend",
        operation="stop_pii_entities_detection_job",
        op_kwargs={"JobId": job_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def disassociate(
    hub, ctx, hosted_zone_id: str, vpc: Dict, comment: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Disassociates an Amazon Virtual Private Cloud (Amazon VPC) from an Amazon Route 53 private hosted zone. Note the following:   You can't disassociate the last Amazon VPC from a private hosted zone.   You can't convert a private hosted zone into a public hosted zone.   You can submit a DisassociateVPCFromHostedZone request using either the account that created the hosted zone or the account that created the Amazon VPC.   Some services, such as Cloud Map and Amazon Elastic File System (Amazon EFS) automatically create hosted zones and associate VPCs with the hosted zones. A service can create a hosted zone using your account or using its own account. You can disassociate a VPC from a hosted zone only if the service created the hosted zone using your account. When you run DisassociateVPCFromHostedZone, if the hosted zone has a value for OwningAccount, you can use DisassociateVPCFromHostedZone. If the hosted zone has a value for OwningService, you can't use DisassociateVPCFromHostedZone.

    Args:
        hosted_zone_id(str): The ID of the private hosted zone that you want to disassociate a VPC from.
        vpc(Dict): A complex type that contains information about the VPC that you're disassociating from the specified hosted zone.
        comment(str, optional):  Optional: A comment about the disassociation request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53.vpc.from_hosted_zone.disassociate(
                ctx, hosted_zone_id=value, vpc=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53.vpc.from_hosted_zone.disassociate hosted_zone_id=value, vpc=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53",
        operation="disassociate_vpc_from_hosted_zone",
        op_kwargs={"HostedZoneId": hosted_zone_id, "VPC": vpc, "Comment": comment},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(hub, ctx, resource_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets the tags for a resource, given its Amazon Resource Names (ARN). This operation supports ARNs for all resource types in Nimble Studio that support tags, including studio, studio component, launch profile, streaming image, and streaming session. All resources that can be tagged will contain an ARN property, so you do not have to create this ARN yourself.

    Args:
        resource_arn(str): The ARN of the target resource for tagging operations.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.nimble.tags_for_resource.list(ctx, resource_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.nimble.tags_for_resource.list resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="nimble",
        operation="list_tags_for_resource",
        op_kwargs={"resourceArn": resource_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(hub, ctx, phone_number_ids: List) -> Dict:
    r"""
    **Autogenerated function**

     Moves phone numbers into the Deletion queue. Phone numbers must be disassociated from any users or Amazon Chime Voice Connectors before they can be deleted.   Phone numbers remain in the Deletion queue for 7 days before they are deleted permanently.

    Args:
        phone_number_ids(List): List of phone number IDs.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.delete_phone_number.batch(ctx, phone_number_ids=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.delete_phone_number.batch phone_number_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="batch_delete_phone_number",
        op_kwargs={"PhoneNumberIds": phone_number_ids},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def stop(hub, ctx, solution_version_arn: str) -> None:
    r"""
    **Autogenerated function**

    Stops creating a solution version that is in a state of CREATE_PENDING or CREATE IN_PROGRESS.  Depending on the current state of the solution version, the solution version state changes as follows:   CREATE_PENDING > CREATE_STOPPED or   CREATE_IN_PROGRESS > CREATE_STOPPING > CREATE_STOPPED   You are billed for all of the training completed up until you stop the solution version creation. You cannot resume creating a solution version once it has been stopped.

    Args:
        solution_version_arn(str): The Amazon Resource Name (ARN) of the solution version you want to stop creating.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.personalize.solution.version.creation.stop(
                ctx, solution_version_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.personalize.solution.version.creation.stop solution_version_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="personalize",
        operation="stop_solution_version_creation",
        op_kwargs={"solutionVersionArn": solution_version_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, user_name: str = None) -> Dict:
    r"""
    **Autogenerated function**

     Creates a new Amazon Web Services secret access key and corresponding Amazon Web Services access key ID for the specified user. The default status for new keys is Active. If you do not specify a user name, IAM determines the user name implicitly based on the Amazon Web Services access key ID signing the request. This operation works for access keys under the account. Consequently, you can use this operation to manage account root user credentials. This is true even if the account has no associated users.  For information about quotas on the number of keys you can create, see IAM and STS quotas in the IAM User Guide.  To ensure the security of your account, the secret access key is accessible only during key and user creation. You must save the key (for example, in a text file) if you want to be able to access it again. If a secret key is lost, you can delete the access keys for the associated user and then create new keys.

    Args:
        user_name(str, optional): The name of the IAM user that the new key will belong to. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.access_key.init.create(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.access_key.init.create
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="create_access_key",
        op_kwargs={"UserName": user_name},
    )


async def delete(hub, ctx, access_key_id: str, user_name: str = None) -> None:
    r"""
    **Autogenerated function**

    Deletes the access key pair associated with the specified IAM user. If you do not specify a user name, IAM determines the user name implicitly based on the Amazon Web Services access key ID signing the request. This operation works for access keys under the account. Consequently, you can use this operation to manage account root user credentials even if the account has no associated users.

    Args:
        user_name(str, optional): The name of the user whose access key pair you want to delete. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-. Defaults to None.
        access_key_id(str): The access key ID for the access key ID and secret access key you want to delete. This parameter allows (through its regex pattern) a string of characters that can consist of any upper or lowercased letter or digit.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.access_key.init.delete(ctx, access_key_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.access_key.init.delete access_key_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="delete_access_key",
        op_kwargs={"UserName": user_name, "AccessKeyId": access_key_id},
    )


async def list_all(
    hub, ctx, user_name: str = None, marker: str = None, max_items: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about the access key IDs associated with the specified IAM user. If there is none, the operation returns an empty list. Although each user is limited to a small number of keys, you can still paginate the results using the MaxItems and Marker parameters. If the UserName field is not specified, the user name is determined implicitly based on the Amazon Web Services access key ID used to sign the request. This operation works for access keys under the account. Consequently, you can use this operation to manage account root user credentials even if the account has no associated users.  To ensure the security of your account, the secret access key is accessible only during key and user creation.

    Args:
        user_name(str, optional): The name of the user. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-. Defaults to None.
        marker(str, optional): Use this parameter only when paginating results and only after you receive a response indicating that the results are truncated. Set it to the value of the Marker element in the response that you received to indicate where the next call should start. Defaults to None.
        max_items(int, optional): Use this only when paginating results to indicate the maximum number of items you want in the response. If additional items exist beyond the maximum you specify, the IsTruncated response element is true. If you do not include this parameter, the number of items defaults to 100. Note that IAM might return fewer results, even when there are more results available. In that case, the IsTruncated response element returns true, and Marker contains a value to include in the subsequent call that tells the service where to continue from. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.access_key.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.access_key.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="list_access_keys",
        op_kwargs={"UserName": user_name, "Marker": marker, "MaxItems": max_items},
    )


async def update(
    hub, ctx, access_key_id: str, status: str, user_name: str = None
) -> None:
    r"""
    **Autogenerated function**

    Changes the status of the specified access key from Active to Inactive, or vice versa. This operation can be used to disable a user's key as part of a key rotation workflow. If the UserName is not specified, the user name is determined implicitly based on the Amazon Web Services access key ID used to sign the request. This operation works for access keys under the account. Consequently, you can use this operation to manage account root user credentials even if the account has no associated users. For information about rotating keys, see Managing keys and certificates in the IAM User Guide.

    Args:
        user_name(str, optional): The name of the user whose key you want to update. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-. Defaults to None.
        access_key_id(str): The access key ID of the secret access key you want to update. This parameter allows (through its regex pattern) a string of characters that can consist of any upper or lowercased letter or digit.
        status(str):  The status you want to assign to the secret access key. Active means that the key can be used for programmatic calls to Amazon Web Services, while Inactive means that the key cannot be used.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.access_key.init.update(
                ctx, access_key_id=value, status=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.access_key.init.update access_key_id=value, status=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="update_access_key",
        op_kwargs={
            "UserName": user_name,
            "AccessKeyId": access_key_id,
            "Status": status,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def put_multiple(
    hub, ctx, email_identity: str, configuration_set_name: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Used to associate a configuration set with an email identity.

    Args:
        email_identity(str): The email address or domain that you want to associate with a configuration set.
        configuration_set_name(str, optional): The configuration set that you want to associate with an email identity. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sesv2.email.identity.configuration_set_attribute.put_multiple(
                ctx, email_identity=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sesv2.email.identity.configuration_set_attribute.put_multiple email_identity=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sesv2",
        operation="put_email_identity_configuration_set_attributes",
        op_kwargs={
            "EmailIdentity": email_identity,
            "ConfigurationSetName": configuration_set_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    subscription_definition_id: str,
    amzn_client_token: str = None,
    subscriptions: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a version of a subscription definition which has already been defined.

    Args:
        amzn_client_token(str, optional): A client token used to correlate requests and responses. Defaults to None.
        subscription_definition_id(str): The ID of the subscription definition.
        subscriptions(List, optional): A list of subscriptions. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrass.subscription_definition.version.create(
                ctx, subscription_definition_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrass.subscription_definition.version.create subscription_definition_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrass",
        operation="create_subscription_definition_version",
        op_kwargs={
            "AmznClientToken": amzn_client_token,
            "SubscriptionDefinitionId": subscription_definition_id,
            "Subscriptions": subscriptions,
        },
    )


async def get(
    hub,
    ctx,
    subscription_definition_id: str,
    subscription_definition_version_id: str,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about a subscription definition version.

    Args:
        next_token(str, optional): The token for the next set of results, or ''null'' if there are no additional results. Defaults to None.
        subscription_definition_id(str): The ID of the subscription definition.
        subscription_definition_version_id(str): The ID of the subscription definition version. This value maps to the ''Version'' property of the corresponding ''VersionInformation'' object, which is returned by ''ListSubscriptionDefinitionVersions'' requests. If the version is the last one that was associated with a subscription definition, the value also maps to the ''LatestVersion'' property of the corresponding ''DefinitionInformation'' object.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrass.subscription_definition.version.get(
                ctx, subscription_definition_id=value, subscription_definition_version_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrass.subscription_definition.version.get subscription_definition_id=value, subscription_definition_version_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrass",
        operation="get_subscription_definition_version",
        op_kwargs={
            "NextToken": next_token,
            "SubscriptionDefinitionId": subscription_definition_id,
            "SubscriptionDefinitionVersionId": subscription_definition_version_id,
        },
    )


async def list_all(
    hub,
    ctx,
    subscription_definition_id: str,
    max_results: str = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the versions of a subscription definition.

    Args:
        max_results(str, optional): The maximum number of results to be returned per request. Defaults to None.
        next_token(str, optional): The token for the next set of results, or ''null'' if there are no additional results. Defaults to None.
        subscription_definition_id(str): The ID of the subscription definition.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrass.subscription_definition.version.list_all(
                ctx, subscription_definition_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrass.subscription_definition.version.list_all subscription_definition_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrass",
        operation="list_subscription_definition_versions",
        op_kwargs={
            "MaxResults": max_results,
            "NextToken": next_token,
            "SubscriptionDefinitionId": subscription_definition_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    instance_id: str,
    name: str,
    type_: str,
    content: str,
    description: str = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a contact flow for the specified Amazon Connect instance. You can also create and update contact flows using the Amazon Connect Flow language.

    Args:
        instance_id(str): The identifier of the Amazon Connect instance.
        name(str): The name of the contact flow.
        type_(str): The type of the contact flow. For descriptions of the available types, see Choose a Contact Flow Type in the Amazon Connect Administrator Guide.
        description(str, optional): The description of the contact flow. . Defaults to None.
        content(str): The content of the contact flow. .
        tags(Dict, optional): One or more tags. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.contact.flow.init.create(
                ctx, instance_id=value, name=value, type_=value, content=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.contact.flow.init.create instance_id=value, name=value, type_=value, content=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="create_contact_flow",
        op_kwargs={
            "InstanceId": instance_id,
            "Name": name,
            "Type": type_,
            "Description": description,
            "Content": content,
            "Tags": tags,
        },
    )


async def describe(hub, ctx, instance_id: str, contact_flow_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes the specified contact flow. You can also create and update contact flows using the Amazon Connect Flow language.

    Args:
        instance_id(str): The identifier of the Amazon Connect instance.
        contact_flow_id(str): The identifier of the contact flow.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.contact.flow.init.describe(
                ctx, instance_id=value, contact_flow_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.contact.flow.init.describe instance_id=value, contact_flow_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="describe_contact_flow",
        op_kwargs={"InstanceId": instance_id, "ContactFlowId": contact_flow_id},
    )


async def list_all(
    hub,
    ctx,
    instance_id: str,
    contact_flow_types: List = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Provides information about the contact flows for the specified Amazon Connect instance. You can also create and update contact flows using the Amazon Connect Flow language. For more information about contact flows, see Contact Flows in the Amazon Connect Administrator Guide.

    Args:
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.
        contact_flow_types(List, optional): The type of contact flow. Defaults to None.
        next_token(str, optional): The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return per page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.contact.flow.init.list_all(ctx, instance_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.contact.flow.init.list_all instance_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="list_contact_flows",
        op_kwargs={
            "InstanceId": instance_id,
            "ContactFlowTypes": contact_flow_types,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    configuration_set_name: str,
    event_destination_name: str,
    event_destination: Dict,
) -> Dict:
    r"""
    **Autogenerated function**

    Create an event destination. In Amazon Pinpoint, events include message sends, deliveries, opens, clicks, bounces, and complaints. Event destinations are places that you can send information about these events to. For example, you can send event data to Amazon SNS to receive notifications when you receive bounces or complaints, or you can use Amazon Kinesis Data Firehose to stream data to Amazon S3 for long-term storage. A single configuration set can include more than one event destination.

    Args:
        configuration_set_name(str): The name of the configuration set that you want to add an event destination to.
        event_destination_name(str): A name that identifies the event destination within the configuration set.
        event_destination(Dict): An object that defines the event destination.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint_email.configuration_set_.event_destination.create(
                ctx,
                configuration_set_name=value,
                event_destination_name=value,
                event_destination=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint_email.configuration_set_.event_destination.create configuration_set_name=value, event_destination_name=value, event_destination=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint-email",
        operation="create_configuration_set_event_destination",
        op_kwargs={
            "ConfigurationSetName": configuration_set_name,
            "EventDestinationName": event_destination_name,
            "EventDestination": event_destination,
        },
    )


async def delete(
    hub, ctx, configuration_set_name: str, event_destination_name: str
) -> Dict:
    r"""
    **Autogenerated function**

    Delete an event destination. In Amazon Pinpoint, events include message sends, deliveries, opens, clicks, bounces, and complaints. Event destinations are places that you can send information about these events to. For example, you can send event data to Amazon SNS to receive notifications when you receive bounces or complaints, or you can use Amazon Kinesis Data Firehose to stream data to Amazon S3 for long-term storage.

    Args:
        configuration_set_name(str): The name of the configuration set that contains the event destination that you want to delete.
        event_destination_name(str): The name of the event destination that you want to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint_email.configuration_set_.event_destination.delete(
                ctx, configuration_set_name=value, event_destination_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint_email.configuration_set_.event_destination.delete configuration_set_name=value, event_destination_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint-email",
        operation="delete_configuration_set_event_destination",
        op_kwargs={
            "ConfigurationSetName": configuration_set_name,
            "EventDestinationName": event_destination_name,
        },
    )


async def get_all(hub, ctx, configuration_set_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieve a list of event destinations that are associated with a configuration set. In Amazon Pinpoint, events include message sends, deliveries, opens, clicks, bounces, and complaints. Event destinations are places that you can send information about these events to. For example, you can send event data to Amazon SNS to receive notifications when you receive bounces or complaints, or you can use Amazon Kinesis Data Firehose to stream data to Amazon S3 for long-term storage.

    Args:
        configuration_set_name(str): The name of the configuration set that contains the event destination.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint_email.configuration_set_.event_destination.get_all(
                ctx, configuration_set_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint_email.configuration_set_.event_destination.get_all configuration_set_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint-email",
        operation="get_configuration_set_event_destinations",
        op_kwargs={"ConfigurationSetName": configuration_set_name},
    )


async def update(
    hub,
    ctx,
    configuration_set_name: str,
    event_destination_name: str,
    event_destination: Dict,
) -> Dict:
    r"""
    **Autogenerated function**

    Update the configuration of an event destination for a configuration set. In Amazon Pinpoint, events include message sends, deliveries, opens, clicks, bounces, and complaints. Event destinations are places that you can send information about these events to. For example, you can send event data to Amazon SNS to receive notifications when you receive bounces or complaints, or you can use Amazon Kinesis Data Firehose to stream data to Amazon S3 for long-term storage.

    Args:
        configuration_set_name(str): The name of the configuration set that contains the event destination that you want to modify.
        event_destination_name(str): The name of the event destination that you want to modify.
        event_destination(Dict): An object that defines the event destination.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint_email.configuration_set_.event_destination.update(
                ctx,
                configuration_set_name=value,
                event_destination_name=value,
                event_destination=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint_email.configuration_set_.event_destination.update configuration_set_name=value, event_destination_name=value, event_destination=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint-email",
        operation="update_configuration_set_event_destination",
        op_kwargs={
            "ConfigurationSetName": configuration_set_name,
            "EventDestinationName": event_destination_name,
            "EventDestination": event_destination,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub, ctx, application_name: str, compute_platform: str = None, tags: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an application.

    Args:
        application_name(str): The name of the application. This name must be unique with the applicable IAM user or AWS account.
        compute_platform(str, optional):  The destination platform type for the deployment (Lambda, Server, or ECS). Defaults to None.
        tags(List, optional):  The metadata that you apply to CodeDeploy applications to help you organize and categorize them. Each tag consists of a key and an optional value, both of which you define. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codedeploy.application.init.create(ctx, application_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codedeploy.application.init.create application_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codedeploy",
        operation="create_application",
        op_kwargs={
            "applicationName": application_name,
            "computePlatform": compute_platform,
            "tags": tags,
        },
    )


async def delete(hub, ctx, application_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes an application.

    Args:
        application_name(str): The name of an AWS CodeDeploy application associated with the IAM user or AWS account.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codedeploy.application.init.delete(ctx, application_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codedeploy.application.init.delete application_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codedeploy",
        operation="delete_application",
        op_kwargs={"applicationName": application_name},
    )


async def get(hub, ctx, application_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about an application.

    Args:
        application_name(str): The name of an AWS CodeDeploy application associated with the IAM user or AWS account.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codedeploy.application.init.get(ctx, application_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codedeploy.application.init.get application_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codedeploy",
        operation="get_application",
        op_kwargs={"applicationName": application_name},
    )


async def list_all(hub, ctx, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists the applications registered with the IAM user or AWS account.

    Args:
        next_token(str, optional): An identifier returned from the previous list applications call. It can be used to return the next set of applications in the list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codedeploy.application.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codedeploy.application.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codedeploy",
        operation="list_applications",
        op_kwargs={"nextToken": next_token},
    )


async def update(
    hub, ctx, application_name: str = None, new_application_name: str = None
) -> None:
    r"""
    **Autogenerated function**

    Changes the name of an application.

    Args:
        application_name(str, optional): The current name of the application you want to change. Defaults to None.
        new_application_name(str, optional): The new name to give the application. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codedeploy.application.init.update(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codedeploy.application.init.update
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codedeploy",
        operation="update_application",
        op_kwargs={
            "applicationName": application_name,
            "newApplicationName": new_application_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def grant(hub, ctx, entitlements: List, flow_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Grants entitlements to an existing flow.

    Args:
        entitlements(List): The list of entitlements that you want to grant.
        flow_arn(str): The flow that you want to grant entitlements on.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediaconnect.flow.entitlement.grant(
                ctx, entitlements=value, flow_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediaconnect.flow.entitlement.grant entitlements=value, flow_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediaconnect",
        operation="grant_flow_entitlements",
        op_kwargs={"Entitlements": entitlements, "FlowArn": flow_arn},
    )


async def revoke(hub, ctx, entitlement_arn: str, flow_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Revokes an entitlement from a flow. Once an entitlement is revoked, the content becomes unavailable to the subscriber and the associated output is removed.

    Args:
        entitlement_arn(str): The ARN of the entitlement that you want to revoke.
        flow_arn(str): The flow that you want to revoke an entitlement from.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediaconnect.flow.entitlement.revoke(
                ctx, entitlement_arn=value, flow_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediaconnect.flow.entitlement.revoke entitlement_arn=value, flow_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediaconnect",
        operation="revoke_flow_entitlement",
        op_kwargs={"EntitlementArn": entitlement_arn, "FlowArn": flow_arn},
    )


async def update(
    hub,
    ctx,
    entitlement_arn: str,
    flow_arn: str,
    description: str = None,
    encryption: Dict = None,
    entitlement_status: str = None,
    subscribers: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    You can change an entitlement's description, subscribers, and encryption. If you change the subscribers, the service will remove the outputs that are are used by the subscribers that are removed.

    Args:
        description(str, optional): A description of the entitlement. This description appears only on the AWS Elemental MediaConnect console and will not be seen by the subscriber or end user. Defaults to None.
        encryption(Dict, optional): The type of encryption that will be used on the output associated with this entitlement. Defaults to None.
        entitlement_arn(str): The ARN of the entitlement that you want to update.
        entitlement_status(str, optional): An indication of whether you want to enable the entitlement to allow access, or disable it to stop streaming content to the subscriber’s flow temporarily. If you don’t specify the entitlementStatus field in your request, MediaConnect leaves the value unchanged. Defaults to None.
        flow_arn(str): The flow that is associated with the entitlement that you want to update.
        subscribers(List, optional): The AWS account IDs that you want to share your content with. The receiving accounts (subscribers) will be allowed to create their own flow using your content as the source. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediaconnect.flow.entitlement.update(
                ctx, entitlement_arn=value, flow_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediaconnect.flow.entitlement.update entitlement_arn=value, flow_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediaconnect",
        operation="update_flow_entitlement",
        op_kwargs={
            "Description": description,
            "Encryption": encryption,
            "EntitlementArn": entitlement_arn,
            "EntitlementStatus": entitlement_status,
            "FlowArn": flow_arn,
            "Subscribers": subscribers,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create_multiple(hub, ctx, workspaces: List) -> Dict:
    r"""
    **Autogenerated function**

    Creates one or more WorkSpaces. This operation is asynchronous and returns before the WorkSpaces are created.

    Args:
        workspaces(List): The WorkSpaces to create. You can specify up to 25 WorkSpaces.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workspace.workspace.init.create_multiple(ctx, workspaces=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workspace.workspace.init.create_multiple workspaces=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workspaces",
        operation="create_workspaces",
        op_kwargs={"Workspaces": workspaces},
    )


async def describe_all(
    hub,
    ctx,
    workspace_ids: List = None,
    directory_id: str = None,
    user_name: str = None,
    bundle_id: str = None,
    limit: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the specified WorkSpaces. You can filter the results by using the bundle identifier, directory identifier, or owner, but you can specify only one filter at a time.

    Args:
        workspace_ids(List, optional): The identifiers of the WorkSpaces. You cannot combine this parameter with any other filter. Because the CreateWorkspaces operation is asynchronous, the identifier it returns is not immediately available. If you immediately call DescribeWorkspaces with this identifier, no information is returned. Defaults to None.
        directory_id(str, optional): The identifier of the directory. In addition, you can optionally specify a specific directory user (see UserName). You cannot combine this parameter with any other filter. Defaults to None.
        user_name(str, optional): The name of the directory user. You must specify this parameter with DirectoryId. Defaults to None.
        bundle_id(str, optional): The identifier of the bundle. All WorkSpaces that are created from this bundle are retrieved. You cannot combine this parameter with any other filter. Defaults to None.
        limit(int, optional): The maximum number of items to return. Defaults to None.
        next_token(str, optional): If you received a NextToken from a previous call that was paginated, provide this token to receive the next set of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workspace.workspace.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workspace.workspace.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workspaces",
        operation="describe_workspaces",
        op_kwargs={
            "WorkspaceIds": workspace_ids,
            "DirectoryId": directory_id,
            "UserName": user_name,
            "BundleId": bundle_id,
            "Limit": limit,
            "NextToken": next_token,
        },
    )


async def migrate(hub, ctx, source_workspace_id: str, bundle_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Migrates a WorkSpace from one operating system or bundle type to another, while retaining the data on the user volume. The migration process recreates the WorkSpace by using a new root volume from the target bundle image and the user volume from the last available snapshot of the original WorkSpace. During migration, the original D:\Users\%USERNAME% user profile folder is renamed to D:\Users\%USERNAME%MMddyyTHHmmss%.NotMigrated. A new D:\Users\%USERNAME%\ folder is generated by the new OS. Certain files in the old user profile are moved to the new user profile. For available migration scenarios, details about what happens during migration, and best practices, see Migrate a WorkSpace.

    Args:
        source_workspace_id(str): The identifier of the WorkSpace to migrate from.
        bundle_id(str): The identifier of the target bundle type to migrate the WorkSpace to.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workspace.workspace.init.migrate(
                ctx, source_workspace_id=value, bundle_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workspace.workspace.init.migrate source_workspace_id=value, bundle_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workspaces",
        operation="migrate_workspace",
        op_kwargs={"SourceWorkspaceId": source_workspace_id, "BundleId": bundle_id},
    )


async def reboot(hub, ctx, reboot_workspace_requests: List) -> Dict:
    r"""
    **Autogenerated function**

    Reboots the specified WorkSpaces. You cannot reboot a WorkSpace unless its state is AVAILABLE or UNHEALTHY. This operation is asynchronous and returns before the WorkSpaces have rebooted.

    Args:
        reboot_workspace_requests(List): The WorkSpaces to reboot. You can specify up to 25 WorkSpaces.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workspace.workspace.init.reboot(
                ctx, reboot_workspace_requests=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workspace.workspace.init.reboot reboot_workspace_requests=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workspaces",
        operation="reboot_workspaces",
        op_kwargs={"RebootWorkspaceRequests": reboot_workspace_requests},
    )


async def rebuild(hub, ctx, rebuild_workspace_requests: List) -> Dict:
    r"""
    **Autogenerated function**

    Rebuilds the specified WorkSpace. You cannot rebuild a WorkSpace unless its state is AVAILABLE, ERROR, UNHEALTHY, STOPPED, or REBOOTING. Rebuilding a WorkSpace is a potentially destructive action that can result in the loss of data. For more information, see Rebuild a WorkSpace. This operation is asynchronous and returns before the WorkSpaces have been completely rebuilt.

    Args:
        rebuild_workspace_requests(List): The WorkSpace to rebuild. You can specify a single WorkSpace.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workspace.workspace.init.rebuild(
                ctx, rebuild_workspace_requests=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workspace.workspace.init.rebuild rebuild_workspace_requests=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workspaces",
        operation="rebuild_workspaces",
        op_kwargs={"RebuildWorkspaceRequests": rebuild_workspace_requests},
    )


async def restore(hub, ctx, workspace_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Restores the specified WorkSpace to its last known healthy state. You cannot restore a WorkSpace unless its state is  AVAILABLE, ERROR, UNHEALTHY, or STOPPED. Restoring a WorkSpace is a potentially destructive action that can result in the loss of data. For more information, see Restore a WorkSpace. This operation is asynchronous and returns before the WorkSpace is completely restored.

    Args:
        workspace_id(str): The identifier of the WorkSpace.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workspace.workspace.init.restore(ctx, workspace_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workspace.workspace.init.restore workspace_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workspaces",
        operation="restore_workspace",
        op_kwargs={"WorkspaceId": workspace_id},
    )


async def start(hub, ctx, start_workspace_requests: List) -> Dict:
    r"""
    **Autogenerated function**

    Starts the specified WorkSpaces. You cannot start a WorkSpace unless it has a running mode of AutoStop and a state of STOPPED.

    Args:
        start_workspace_requests(List): The WorkSpaces to start. You can specify up to 25 WorkSpaces.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workspace.workspace.init.start(
                ctx, start_workspace_requests=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workspace.workspace.init.start start_workspace_requests=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workspaces",
        operation="start_workspaces",
        op_kwargs={"StartWorkspaceRequests": start_workspace_requests},
    )


async def stop(hub, ctx, stop_workspace_requests: List) -> Dict:
    r"""
    **Autogenerated function**

     Stops the specified WorkSpaces. You cannot stop a WorkSpace unless it has a running mode of AutoStop and a state of AVAILABLE, IMPAIRED, UNHEALTHY, or ERROR.

    Args:
        stop_workspace_requests(List): The WorkSpaces to stop. You can specify up to 25 WorkSpaces.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workspace.workspace.init.stop(
                ctx, stop_workspace_requests=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workspace.workspace.init.stop stop_workspace_requests=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workspaces",
        operation="stop_workspaces",
        op_kwargs={"StopWorkspaceRequests": stop_workspace_requests},
    )


async def terminate(hub, ctx, terminate_workspace_requests: List) -> Dict:
    r"""
    **Autogenerated function**

    Terminates the specified WorkSpaces.  Terminating a WorkSpace is a permanent action and cannot be undone. The user's data is destroyed. If you need to archive any user data, contact AWS Support before terminating the WorkSpace.  You can terminate a WorkSpace that is in any state except SUSPENDED. This operation is asynchronous and returns before the WorkSpaces have been completely terminated. After a WorkSpace is terminated, the TERMINATED state is returned only briefly before the WorkSpace directory metadata is cleaned up, so this state is rarely returned. To confirm that a WorkSpace is terminated, check for the WorkSpace ID by using  DescribeWorkSpaces. If the WorkSpace ID isn't returned, then the WorkSpace has been successfully terminated.  Simple AD and AD Connector are made available to you free of charge to use with WorkSpaces. If there are no WorkSpaces being used with your Simple AD or AD Connector directory for 30 consecutive days, this directory will be automatically deregistered for use with Amazon WorkSpaces, and you will be charged for this directory as per the AWS Directory Services pricing terms. To delete empty directories, see  Delete the Directory for Your WorkSpaces. If you delete your Simple AD or AD Connector directory, you can always create a new one when you want to start using WorkSpaces again.

    Args:
        terminate_workspace_requests(List): The WorkSpaces to terminate. You can specify up to 25 WorkSpaces.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workspace.workspace.init.terminate(
                ctx, terminate_workspace_requests=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workspace.workspace.init.terminate terminate_workspace_requests=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workspaces",
        operation="terminate_workspaces",
        op_kwargs={"TerminateWorkspaceRequests": terminate_workspace_requests},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def send(hub, ctx, notification: Dict, test_event_type: str) -> Dict:
    r"""
    **Autogenerated function**

     The SendTestEventNotification operation causes Amazon Mechanical Turk to send a notification message as if a HIT event occurred, according to the provided notification specification. This allows you to test notifications without setting up notifications for a real HIT type and trying to trigger them using the website. When you call this operation, the service attempts to send the test notification immediately.

    Args:
        notification(Dict):  The notification specification to test. This value is identical to the value you would provide to the UpdateNotificationSettings operation when you establish the notification specification for a HIT type. .
        test_event_type(str):  The event to simulate to test the notification specification. This event is included in the test message even if the notification specification does not include the event type. The notification specification does not filter out the test event. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mturk.test_event_notification.send(
                ctx, notification=value, test_event_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mturk.test_event_notification.send notification=value, test_event_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mturk",
        operation="send_test_event_notification",
        op_kwargs={"Notification": notification, "TestEventType": test_event_type},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def record(hub, ctx, task_token: str, details: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Used by activity workers to report to the service that the ActivityTask represented by the specified taskToken is still making progress. The worker can also specify details of the progress, for example percent complete, using the details parameter. This action can also be used by the worker as a mechanism to check if cancellation is being requested for the activity task. If a cancellation is being attempted for the specified task, then the boolean cancelRequested flag returned by the service is set to true. This action resets the taskHeartbeatTimeout clock. The taskHeartbeatTimeout is specified in RegisterActivityType. This action doesn't in itself create an event in the workflow execution history. However, if the task times out, the workflow execution history contains a ActivityTaskTimedOut event that contains the information from the last heartbeat generated by the activity worker.  The taskStartToCloseTimeout of an activity type is the maximum duration of an activity task, regardless of the number of RecordActivityTaskHeartbeat requests received. The taskStartToCloseTimeout is also specified in RegisterActivityType.   This operation is only useful for long-lived activities to report liveliness of the task and to determine if a cancellation is being attempted.   If the cancelRequested flag returns true, a cancellation is being attempted. If the worker can cancel the activity, it should respond with RespondActivityTaskCanceled. Otherwise, it should ignore the cancellation request.   Access Control  You can use IAM policies to control this action's access to Amazon SWF resources as follows:   Use a Resource element with the domain name to limit the action to only specified domains.   Use an Action element to allow or deny permission to call this action.   You cannot use an IAM policy to constrain this action's parameters.   If the caller doesn't have sufficient permissions to invoke the action, or the parameter values fall outside the specified constraints, the action fails. The associated event attribute's cause parameter is set to OPERATION_NOT_PERMITTED. For details and example IAM policies, see Using IAM to Manage Access to Amazon SWF Workflows in the Amazon SWF Developer Guide.

    Args:
        task_token(str): The taskToken of the ActivityTask.   taskToken is generated by the service and should be treated as an opaque value. If the task is passed to another process, its taskToken must also be passed. This enables it to provide its progress and respond with results.  .
        details(str, optional): If specified, contains details about the progress of the task. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.swf.activity.task.heartbeat.record(ctx, task_token=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.swf.activity.task.heartbeat.record task_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="swf",
        operation="record_activity_task_heartbeat",
        op_kwargs={"taskToken": task_token, "details": details},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(hub, ctx, configuration_ids: List) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves attributes for a list of configuration item IDs.  All of the supplied IDs must be for the same asset type from one of the following:   server   application   process   connection   Output fields are specific to the asset type specified. For example, the output for a server configuration item includes a list of attributes about the server, such as host name, operating system, number of network cards, etc. For a complete list of outputs for each asset type, see Using the DescribeConfigurations Action in the AWS Application Discovery Service User Guide.

    Args:
        configuration_ids(List): One or more configuration IDs.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.discovery.configuration.init.describe_all(
                ctx, configuration_ids=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.discovery.configuration.init.describe_all configuration_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="discovery",
        operation="describe_configurations",
        op_kwargs={"configurationIds": configuration_ids},
    )


async def export(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Deprecated. Use StartExportTask instead. Exports all discovered configuration data to an Amazon S3 bucket or an application that enables you to view and evaluate the data. Data includes tags and tag associations, processes, connections, servers, and system performance. This API returns an export ID that you can query using the DescribeExportConfigurations API. The system imposes a limit of two configuration exports in six hours.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.discovery.configuration.init.export(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.discovery.configuration.init.export
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="discovery", operation="export_configurations", op_kwargs={}
    )


async def list_all(
    hub,
    ctx,
    configuration_type: str,
    filters: List = None,
    max_results: int = None,
    next_token: str = None,
    order_by: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a list of configuration items as specified by the value passed to the required parameter configurationType. Optional filtering may be applied to refine search results.

    Args:
        configuration_type(str): A valid configuration identified by Application Discovery Service. .
        filters(List, optional): You can filter the request using various logical operators and a key-value format. For example:   {"key": "serverType", "value": "webServer"}  For a complete list of filter options and guidance about using them with this action, see Using the ListConfigurations Action in the AWS Application Discovery Service User Guide. Defaults to None.
        max_results(int, optional): The total number of items to return. The maximum value is 100. Defaults to None.
        next_token(str, optional): Token to retrieve the next set of results. For example, if a previous call to ListConfigurations returned 100 items, but you set ListConfigurationsRequest$maxResults to 10, you received a set of 10 results along with a token. Use that token in this query to get the next set of 10. Defaults to None.
        order_by(List, optional): Certain filter criteria return output that can be sorted in ascending or descending order. For a list of output characteristics for each filter, see Using the ListConfigurations Action in the AWS Application Discovery Service User Guide. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.discovery.configuration.init.list_all(
                ctx, configuration_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.discovery.configuration.init.list_all configuration_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="discovery",
        operation="list_configurations",
        op_kwargs={
            "configurationType": configuration_type,
            "filters": filters,
            "maxResults": max_results,
            "nextToken": next_token,
            "orderBy": order_by,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get(hub, ctx, deployment_id: str, instance_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about an instance as part of a deployment.

    Args:
        deployment_id(str):  The unique ID of a deployment. .
        instance_id(str):  The unique ID of an instance in the deployment group. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codedeploy.deployment.instance.get(
                ctx, deployment_id=value, instance_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codedeploy.deployment.instance.get deployment_id=value, instance_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codedeploy",
        operation="get_deployment_instance",
        op_kwargs={"deploymentId": deployment_id, "instanceId": instance_id},
    )


async def list_all(
    hub,
    ctx,
    deployment_id: str,
    next_token: str = None,
    instance_status_filter: List = None,
    instance_type_filter: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

      The newer BatchGetDeploymentTargets should be used instead because it works with all compute types. ListDeploymentInstances throws an exception if it is used with a compute platform other than EC2/On-premises or AWS Lambda.    Lists the instance for a deployment associated with the IAM user or AWS account.

    Args:
        deployment_id(str):  The unique ID of a deployment. .
        next_token(str, optional): An identifier returned from the previous list deployment instances call. It can be used to return the next set of deployment instances in the list. Defaults to None.
        instance_status_filter(List, optional): A subset of instances to list by status:    Pending: Include those instances with pending deployments.    InProgress: Include those instances where deployments are still in progress.    Succeeded: Include those instances with successful deployments.    Failed: Include those instances with failed deployments.    Skipped: Include those instances with skipped deployments.    Unknown: Include those instances with deployments in an unknown state.  . Defaults to None.
        instance_type_filter(List, optional): The set of instances in a blue/green deployment, either those in the original environment ("BLUE") or those in the replacement environment ("GREEN"), for which you want to view instance information. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codedeploy.deployment.instance.list_all(
                ctx, deployment_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codedeploy.deployment.instance.list_all deployment_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codedeploy",
        operation="list_deployment_instances",
        op_kwargs={
            "deploymentId": deployment_id,
            "nextToken": next_token,
            "instanceStatusFilter": instance_status_filter,
            "instanceTypeFilter": instance_type_filter,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, pull_request_id: str, revision_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about whether approval rules have been set aside (overridden) for a pull request, and if so, the Amazon Resource Name (ARN) of the user or identity that overrode the rules and their requirements for the pull request.

    Args:
        pull_request_id(str): The ID of the pull request for which you want to get information about whether approval rules have been set aside (overridden).
        revision_id(str): The system-generated ID of the revision for the pull request. To retrieve the most recent revision ID, use GetPullRequest.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codecommit.pull_request.override_state.get(
                ctx, pull_request_id=value, revision_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codecommit.pull_request.override_state.get pull_request_id=value, revision_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codecommit",
        operation="get_pull_request_override_state",
        op_kwargs={"pullRequestId": pull_request_id, "revisionId": revision_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get_all(hub, ctx, detector_id: str, account_ids: List) -> Dict:
    r"""
    **Autogenerated function**

    Describes which data sources are enabled for the member account's detector.

    Args:
        detector_id(str): The detector ID for the administrator account.
        account_ids(List): The account ID of the member account.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.guardduty.member.detector.get_all(
                ctx, detector_id=value, account_ids=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.guardduty.member.detector.get_all detector_id=value, account_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="guardduty",
        operation="get_member_detectors",
        op_kwargs={"DetectorId": detector_id, "AccountIds": account_ids},
    )


async def update_multiple(
    hub, ctx, detector_id: str, account_ids: List, data_sources: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    Contains information on member accounts to be updated.

    Args:
        detector_id(str): The detector ID of the administrator account.
        account_ids(List): A list of member account IDs to be updated.
        data_sources(Dict, optional): Describes which data sources will be updated. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.guardduty.member.detector.update_multiple(
                ctx, detector_id=value, account_ids=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.guardduty.member.detector.update_multiple detector_id=value, account_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="guardduty",
        operation="update_member_detectors",
        op_kwargs={
            "DetectorId": detector_id,
            "AccountIds": account_ids,
            "DataSources": data_sources,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, application_id: str, write_journey_request: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Creates a journey for an application.

    Args:
        application_id(str): The unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.
        write_journey_request(Dict): Specifies the configuration and other settings for a journey.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint.journey.init.create(
                ctx, application_id=value, write_journey_request=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint.journey.init.create application_id=value, write_journey_request=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint",
        operation="create_journey",
        op_kwargs={
            "ApplicationId": application_id,
            "WriteJourneyRequest": write_journey_request,
        },
    )


async def delete(hub, ctx, application_id: str, journey_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a journey from an application.

    Args:
        application_id(str): The unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.
        journey_id(str): The unique identifier for the journey.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint.journey.init.delete(
                ctx, application_id=value, journey_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint.journey.init.delete application_id=value, journey_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint",
        operation="delete_journey",
        op_kwargs={"ApplicationId": application_id, "JourneyId": journey_id},
    )


async def get(hub, ctx, application_id: str, journey_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about the status, configuration, and other settings for a journey.

    Args:
        application_id(str): The unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.
        journey_id(str): The unique identifier for the journey.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint.journey.init.get(
                ctx, application_id=value, journey_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint.journey.init.get application_id=value, journey_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint",
        operation="get_journey",
        op_kwargs={"ApplicationId": application_id, "JourneyId": journey_id},
    )


async def list_all(
    hub, ctx, application_id: str, page_size: str = None, token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about the status, configuration, and other settings for all the journeys that are associated with an application.

    Args:
        application_id(str): The unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.
        page_size(str, optional): The maximum number of items to include in each page of a paginated response. This parameter is not supported for application, campaign, and journey metrics. Defaults to None.
        token(str, optional): The NextToken string that specifies which page of results to return in a paginated response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint.journey.init.list_all(ctx, application_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint.journey.init.list_all application_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint",
        operation="list_journeys",
        op_kwargs={
            "ApplicationId": application_id,
            "PageSize": page_size,
            "Token": token,
        },
    )


async def update(
    hub, ctx, application_id: str, journey_id: str, write_journey_request: Dict
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the configuration and other settings for a journey.

    Args:
        application_id(str): The unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.
        journey_id(str): The unique identifier for the journey.
        write_journey_request(Dict): Specifies the configuration and other settings for a journey.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint.journey.init.update(
                ctx, application_id=value, journey_id=value, write_journey_request=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint.journey.init.update application_id=value, journey_id=value, write_journey_request=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint",
        operation="update_journey",
        op_kwargs={
            "ApplicationId": application_id,
            "JourneyId": journey_id,
            "WriteJourneyRequest": write_journey_request,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def respond(
    hub,
    ctx,
    client_id: str,
    challenge_name: str,
    session: str = None,
    challenge_responses: Dict = None,
    analytics_metadata: Dict = None,
    user_context_data: Dict = None,
    client_metadata: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Responds to the authentication challenge.  This action might generate an SMS text message. Starting June 1, 2021, U.S. telecom carriers require that you register an origination phone number before you can send SMS messages to U.S. phone numbers. If you use SMS text messages in Amazon Cognito, you must register a phone number with Amazon Pinpoint. Cognito will use the the registered number automatically. Otherwise, Cognito users that must receive SMS messages might be unable to sign up, activate their accounts, or sign in. If you have never used SMS text messages with Amazon Cognito or any other Amazon Web Service, Amazon SNS might place your account in SMS sandbox. In  sandbox mode , you’ll have limitations, such as sending messages to only verified phone numbers. After testing in the sandbox environment, you can move out of the SMS sandbox and into production. For more information, see  SMS message settings for Cognito User Pools in the Amazon Cognito Developer Guide.

    Args:
        client_id(str): The app client ID.
        challenge_name(str): The challenge name. For more information, see InitiateAuth.  ADMIN_NO_SRP_AUTH is not a valid value.
        session(str, optional): The session which should be passed both ways in challenge-response calls to the service. If InitiateAuth or RespondToAuthChallenge API call determines that the caller needs to go through another challenge, they return a session with other challenge parameters. This session should be passed as it is to the next RespondToAuthChallenge API call. Defaults to None.
        challenge_responses(Dict, optional): The challenge responses. These are inputs corresponding to the value of ChallengeName, for example:   SECRET_HASH (if app client is configured with client secret) applies to all inputs below (including SOFTWARE_TOKEN_MFA).     SMS_MFA: SMS_MFA_CODE, USERNAME.    PASSWORD_VERIFIER: PASSWORD_CLAIM_SIGNATURE, PASSWORD_CLAIM_SECRET_BLOCK, TIMESTAMP, USERNAME.    NEW_PASSWORD_REQUIRED: NEW_PASSWORD, any other required attributes, USERNAME.     SOFTWARE_TOKEN_MFA: USERNAME and SOFTWARE_TOKEN_MFA_CODE are required attributes.    DEVICE_SRP_AUTH requires USERNAME, DEVICE_KEY, SRP_A (and SECRET_HASH).    DEVICE_PASSWORD_VERIFIER requires everything that PASSWORD_VERIFIER requires plus DEVICE_KEY.    MFA_SETUP requires USERNAME, plus you need to use the session value returned by VerifySoftwareToken in the Session parameter.  . Defaults to None.
        analytics_metadata(Dict, optional): The Amazon Pinpoint analytics metadata for collecting metrics for RespondToAuthChallenge calls. Defaults to None.
        user_context_data(Dict, optional): Contextual data such as the user's device fingerprint, IP address, or location used for evaluating the risk of an unexpected event by Amazon Cognito advanced security. Defaults to None.
        client_metadata(Dict, optional): A map of custom key-value pairs that you can provide as input for any custom workflows that this action triggers.  You create custom workflows by assigning Lambda functions to user pool triggers. When you use the RespondToAuthChallenge API action, Amazon Cognito invokes any functions that are assigned to the following triggers: post authentication, pre token generation, define auth challenge, create auth challenge, and verify auth challenge. When Amazon Cognito invokes any of these functions, it passes a JSON payload, which the function receives as input. This payload contains a clientMetadata attribute, which provides the data that you assigned to the ClientMetadata parameter in your RespondToAuthChallenge request. In your function code in Lambda, you can process the clientMetadata value to enhance your workflow for your specific needs. For more information, see Customizing User Pool Workflows with Lambda Triggers in the Amazon Cognito Developer Guide.  Take the following limitations into consideration when you use the ClientMetadata parameter:   Amazon Cognito does not store the ClientMetadata value. This data is available only to Lambda triggers that are assigned to a user pool to support custom workflows. If your user pool configuration does not include triggers, the ClientMetadata parameter serves no purpose.   Amazon Cognito does not validate the ClientMetadata value.   Amazon Cognito does not encrypt the the ClientMetadata value, so don't use it to provide sensitive information.   . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.to.auth_challenge.respond(
                ctx, client_id=value, challenge_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.to.auth_challenge.respond client_id=value, challenge_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="respond_to_auth_challenge",
        op_kwargs={
            "ClientId": client_id,
            "ChallengeName": challenge_name,
            "Session": session,
            "ChallengeResponses": challenge_responses,
            "AnalyticsMetadata": analytics_metadata,
            "UserContextData": user_context_data,
            "ClientMetadata": client_metadata,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def record(
    hub,
    ctx,
    lifecycle_hook_name: str,
    auto_scaling_group_name: str,
    lifecycle_action_token: str = None,
    instance_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Records a heartbeat for the lifecycle action associated with the specified token or instance. This extends the timeout by the length of time defined using the PutLifecycleHook API call. This step is a part of the procedure for adding a lifecycle hook to an Auto Scaling group:   (Optional) Create a Lambda function and a rule that allows CloudWatch Events to invoke your Lambda function when Amazon EC2 Auto Scaling launches or terminates instances.   (Optional) Create a notification target and an IAM role. The target can be either an Amazon SQS queue or an Amazon SNS topic. The role allows Amazon EC2 Auto Scaling to publish lifecycle notifications to the target.   Create the lifecycle hook. Specify whether the hook is used when the instances launch or terminate.    If you need more time, record the lifecycle action heartbeat to keep the instance in a pending state.    If you finish before the timeout period ends, complete the lifecycle action.   For more information, see Amazon EC2 Auto Scaling lifecycle hooks in the Amazon EC2 Auto Scaling User Guide.

    Args:
        lifecycle_hook_name(str): The name of the lifecycle hook.
        auto_scaling_group_name(str): The name of the Auto Scaling group.
        lifecycle_action_token(str, optional): A token that uniquely identifies a specific lifecycle action associated with an instance. Amazon EC2 Auto Scaling sends this token to the notification target that you specified when you created the lifecycle hook. Defaults to None.
        instance_id(str, optional): The ID of the instance. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.autoscaling.lifecycle.action.heartbeat.record(
                ctx, lifecycle_hook_name=value, auto_scaling_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.autoscaling.lifecycle.action.heartbeat.record lifecycle_hook_name=value, auto_scaling_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="autoscaling",
        operation="record_lifecycle_action_heartbeat",
        op_kwargs={
            "LifecycleHookName": lifecycle_hook_name,
            "AutoScalingGroupName": auto_scaling_group_name,
            "LifecycleActionToken": lifecycle_action_token,
            "InstanceId": instance_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    filters: List = None,
    offering_class: str = None,
    reserved_instances_ids: List = None,
    dry_run: bool = None,
    offering_type: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes one or more of the Reserved Instances that you purchased. For more information about Reserved Instances, see Reserved Instances in the Amazon EC2 User Guide.

    Args:
        filters(List, optional): One or more filters.    availability-zone - The Availability Zone where the Reserved Instance can be used.    duration - The duration of the Reserved Instance (one year or three years), in seconds (31536000 | 94608000).    end - The time when the Reserved Instance expires (for example, 2015-08-07T11:54:42.000Z).    fixed-price - The purchase price of the Reserved Instance (for example, 9800.0).    instance-type - The instance type that is covered by the reservation.    scope - The scope of the Reserved Instance (Region or Availability Zone).    product-description - The Reserved Instance product platform description. Instances that include (Amazon VPC) in the product platform description will only be displayed to EC2-Classic account holders and are for use with Amazon VPC (Linux/UNIX | Linux/UNIX (Amazon VPC) | SUSE Linux | SUSE Linux (Amazon VPC) | Red Hat Enterprise Linux | Red Hat Enterprise Linux (Amazon VPC) | Red Hat Enterprise Linux with HA (Amazon VPC) | Windows | Windows (Amazon VPC) | Windows with SQL Server Standard | Windows with SQL Server Standard (Amazon VPC) | Windows with SQL Server Web | Windows with SQL Server Web (Amazon VPC) | Windows with SQL Server Enterprise | Windows with SQL Server Enterprise (Amazon VPC)).    reserved-instances-id - The ID of the Reserved Instance.    start - The time at which the Reserved Instance purchase request was placed (for example, 2014-08-07T11:54:42.000Z).    state - The state of the Reserved Instance (payment-pending | active | payment-failed | retired).    tag:<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.    usage-price - The usage price of the Reserved Instance, per hour (for example, 0.84).  . Defaults to None.
        offering_class(str, optional): Describes whether the Reserved Instance is Standard or Convertible. Defaults to None.
        reserved_instances_ids(List, optional): One or more Reserved Instance IDs. Default: Describes all your Reserved Instances, or only those otherwise specified. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        offering_type(str, optional): The Reserved Instance offering type. If you are using tools that predate the 2011-11-01 API version, you only have access to the Medium Utilization Reserved Instance offering type. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.reserved_instance.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.reserved_instance.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_reserved_instances",
        op_kwargs={
            "Filters": filters,
            "OfferingClass": offering_class,
            "ReservedInstancesIds": reserved_instances_ids,
            "DryRun": dry_run,
            "OfferingType": offering_type,
        },
    )


async def modify(
    hub,
    ctx,
    reserved_instances_ids: List,
    target_configurations: List,
    client_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies the Availability Zone, instance count, instance type, or network platform (EC2-Classic or EC2-VPC) of your Reserved Instances. The Reserved Instances to be modified must be identical, except for Availability Zone, network platform, and instance type. For more information, see Modifying Reserved Instances in the Amazon EC2 User Guide.

    Args:
        reserved_instances_ids(List): The IDs of the Reserved Instances to modify.
        client_token(str, optional): A unique, case-sensitive token you provide to ensure idempotency of your modification request. For more information, see Ensuring Idempotency. Defaults to None.
        target_configurations(List): The configuration settings for the Reserved Instances to modify.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.reserved_instance.init.modify(
                ctx, reserved_instances_ids=value, target_configurations=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.reserved_instance.init.modify reserved_instances_ids=value, target_configurations=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="modify_reserved_instances",
        op_kwargs={
            "ReservedInstancesIds": reserved_instances_ids,
            "ClientToken": client_token,
            "TargetConfigurations": target_configurations,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get(hub, ctx, token: str, token_properties: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Gets a temporary access token to use with AssumeRoleWithWebIdentity. Access tokens are valid for one hour.

    Args:
        token(str): Refresh token, encoded as a JWT token.
        token_properties(List, optional): Token properties to validate against those present in the JWT token. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.license_manager.access_token.get(ctx, token=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.license_manager.access_token.get token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="license-manager",
        operation="get_access_token",
        op_kwargs={"Token": token, "TokenProperties": token_properties},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, streaming_distribution_config: Dict) -> Dict:
    r"""
    **Autogenerated function**

    This API is deprecated. Amazon CloudFront is deprecating real-time messaging protocol (RTMP) distributions on December 31, 2020. For more information, read the announcement on the Amazon CloudFront discussion forum.

    Args:
        streaming_distribution_config(Dict): The streaming distribution's configuration information.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudfront.streaming_distribution.init.create(
                ctx, streaming_distribution_config=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudfront.streaming_distribution.init.create streaming_distribution_config=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudfront",
        operation="create_streaming_distribution",
        op_kwargs={"StreamingDistributionConfig": streaming_distribution_config},
    )


async def delete(hub, ctx, id_: str, if_match: str = None) -> None:
    r"""
    **Autogenerated function**

    Delete a streaming distribution. To delete an RTMP distribution using the CloudFront API, perform the following steps.  To delete an RTMP distribution using the CloudFront API:   Disable the RTMP distribution.   Submit a GET Streaming Distribution Config request to get the current configuration and the Etag header for the distribution.    Update the XML document that was returned in the response to your GET Streaming Distribution Config request to change the value of Enabled to false.   Submit a PUT Streaming Distribution Config request to update the configuration for your distribution. In the request body, include the XML document that you updated in Step 3. Then set the value of the HTTP If-Match header to the value of the ETag header that CloudFront returned when you submitted the GET Streaming Distribution Config request in Step 2.   Review the response to the PUT Streaming Distribution Config request to confirm that the distribution was successfully disabled.   Submit a GET Streaming Distribution Config request to confirm that your changes have propagated. When propagation is complete, the value of Status is Deployed.   Submit a DELETE Streaming Distribution request. Set the value of the HTTP If-Match header to the value of the ETag header that CloudFront returned when you submitted the GET Streaming Distribution Config request in Step 2.   Review the response to your DELETE Streaming Distribution request to confirm that the distribution was successfully deleted.   For information about deleting a distribution using the CloudFront console, see Deleting a Distribution in the Amazon CloudFront Developer Guide.

    Args:
        id_(str): The distribution ID. .
        if_match(str, optional): The value of the ETag header that you received when you disabled the streaming distribution. For example: E2QWRUHAPOMQZL. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudfront.streaming_distribution.init.delete(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudfront.streaming_distribution.init.delete id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudfront",
        operation="delete_streaming_distribution",
        op_kwargs={"Id": id_, "IfMatch": if_match},
    )


async def get(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about a specified RTMP distribution, including the distribution configuration.

    Args:
        id_(str): The streaming distribution's ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudfront.streaming_distribution.init.get(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudfront.streaming_distribution.init.get id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudfront",
        operation="get_streaming_distribution",
        op_kwargs={"Id": id_},
    )


async def list_all(hub, ctx, marker: str = None, max_items: str = None) -> Dict:
    r"""
    **Autogenerated function**

    List streaming distributions.

    Args:
        marker(str, optional): The value that you provided for the Marker request parameter. Defaults to None.
        max_items(str, optional): The value that you provided for the MaxItems request parameter. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudfront.streaming_distribution.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudfront.streaming_distribution.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudfront",
        operation="list_streaming_distributions",
        op_kwargs={"Marker": marker, "MaxItems": max_items},
    )


async def update(
    hub, ctx, streaming_distribution_config: Dict, id_: str, if_match: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Update a streaming distribution.

    Args:
        streaming_distribution_config(Dict): The streaming distribution's configuration information.
        id_(str): The streaming distribution's id.
        if_match(str, optional): The value of the ETag header that you received when retrieving the streaming distribution's configuration. For example: E2QWRUHAPOMQZL. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudfront.streaming_distribution.init.update(
                ctx, streaming_distribution_config=value, id_=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudfront.streaming_distribution.init.update streaming_distribution_config=value, id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudfront",
        operation="update_streaming_distribution",
        op_kwargs={
            "StreamingDistributionConfig": streaming_distribution_config,
            "Id": id_,
            "IfMatch": if_match,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, log_group_name: str, log_stream_name: str) -> None:
    r"""
    **Autogenerated function**

    Creates a log stream for the specified log group. A log stream is a sequence of log events that originate from a single source, such as an application instance or a resource that is being monitored. There is no limit on the number of log streams that you can create for a log group. There is a limit of 50 TPS on CreateLogStream operations, after which transactions are throttled. You must use the following guidelines when naming a log stream:   Log stream names must be unique within the log group.   Log stream names can be between 1 and 512 characters long.   The ':' (colon) and '*' (asterisk) characters are not allowed.

    Args:
        log_group_name(str): The name of the log group.
        log_stream_name(str): The name of the log stream.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.logs.log.stream.create(
                ctx, log_group_name=value, log_stream_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.logs.log.stream.create log_group_name=value, log_stream_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="logs",
        operation="create_log_stream",
        op_kwargs={"logGroupName": log_group_name, "logStreamName": log_stream_name},
    )


async def delete(hub, ctx, log_group_name: str, log_stream_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified log stream and permanently deletes all the archived log events associated with the log stream.

    Args:
        log_group_name(str): The name of the log group.
        log_stream_name(str): The name of the log stream.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.logs.log.stream.delete(
                ctx, log_group_name=value, log_stream_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.logs.log.stream.delete log_group_name=value, log_stream_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="logs",
        operation="delete_log_stream",
        op_kwargs={"logGroupName": log_group_name, "logStreamName": log_stream_name},
    )


async def describe_all(
    hub,
    ctx,
    log_group_name: str,
    log_stream_name_prefix: str = None,
    order_by: str = None,
    descending: bool = None,
    next_token: str = None,
    limit: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the log streams for the specified log group. You can list all the log streams or filter the results by prefix. You can also control how the results are ordered. This operation has a limit of five transactions per second, after which transactions are throttled.

    Args:
        log_group_name(str): The name of the log group.
        log_stream_name_prefix(str, optional): The prefix to match. If orderBy is LastEventTime, you cannot specify this parameter. Defaults to None.
        order_by(str, optional): If the value is LogStreamName, the results are ordered by log stream name. If the value is LastEventTime, the results are ordered by the event time. The default value is LogStreamName. If you order the results by event time, you cannot specify the logStreamNamePrefix parameter.  lastEventTimestamp represents the time of the most recent log event in the log stream in CloudWatch Logs. This number is expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC. lastEventTimestamp updates on an eventual consistency basis. It typically updates in less than an hour from ingestion, but in rare situations might take longer. Defaults to None.
        descending(bool, optional): If the value is true, results are returned in descending order. If the value is to false, results are returned in ascending order. The default value is false. Defaults to None.
        next_token(str, optional): The token for the next set of items to return. (You received this token from a previous call.). Defaults to None.
        limit(int, optional): The maximum number of items returned. If you don't specify a value, the default is up to 50 items. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.logs.log.stream.describe_all(ctx, log_group_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.logs.log.stream.describe_all log_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="logs",
        operation="describe_log_streams",
        op_kwargs={
            "logGroupName": log_group_name,
            "logStreamNamePrefix": log_stream_name_prefix,
            "orderBy": order_by,
            "descending": descending,
            "nextToken": next_token,
            "limit": limit,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    username: str,
    phone_config: Dict,
    security_profile_ids: List,
    routing_profile_id: str,
    instance_id: str,
    password: str = None,
    identity_info: Dict = None,
    directory_user_id: str = None,
    hierarchy_group_id: str = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a user account for the specified Amazon Connect instance. For information about how to create user accounts using the Amazon Connect console, see Add Users in the Amazon Connect Administrator Guide.

    Args:
        username(str): The user name for the account. For instances not using SAML for identity management, the user name can include up to 20 characters. If you are using SAML for identity management, the user name can include up to 64 characters from [a-zA-Z0-9_-.\@]+.
        password(str, optional): The password for the user account. A password is required if you are using Amazon Connect for identity management. Otherwise, it is an error to include a password. Defaults to None.
        identity_info(Dict, optional): The information about the identity of the user. Defaults to None.
        phone_config(Dict): The phone settings for the user.
        directory_user_id(str, optional): The identifier of the user account in the directory used for identity management. If Amazon Connect cannot access the directory, you can specify this identifier to authenticate users. If you include the identifier, we assume that Amazon Connect cannot access the directory. Otherwise, the identity information is used to authenticate users from your directory. This parameter is required if you are using an existing directory for identity management in Amazon Connect when Amazon Connect cannot access your directory to authenticate users. If you are using SAML for identity management and include this parameter, an error is returned. Defaults to None.
        security_profile_ids(List): The identifier of the security profile for the user.
        routing_profile_id(str): The identifier of the routing profile for the user.
        hierarchy_group_id(str, optional): The identifier of the hierarchy group for the user. Defaults to None.
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.
        tags(Dict, optional): One or more tags. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.user.init.create(
                ctx,
                username=value,
                phone_config=value,
                security_profile_ids=value,
                routing_profile_id=value,
                instance_id=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.user.init.create username=value, phone_config=value, security_profile_ids=value, routing_profile_id=value, instance_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="create_user",
        op_kwargs={
            "Username": username,
            "Password": password,
            "IdentityInfo": identity_info,
            "PhoneConfig": phone_config,
            "DirectoryUserId": directory_user_id,
            "SecurityProfileIds": security_profile_ids,
            "RoutingProfileId": routing_profile_id,
            "HierarchyGroupId": hierarchy_group_id,
            "InstanceId": instance_id,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, instance_id: str, user_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a user account from the specified Amazon Connect instance. For information about what happens to a user's data when their account is deleted, see Delete Users from Your Amazon Connect Instance in the Amazon Connect Administrator Guide.

    Args:
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.
        user_id(str): The identifier of the user.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.user.init.delete(ctx, instance_id=value, user_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.user.init.delete instance_id=value, user_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="delete_user",
        op_kwargs={"InstanceId": instance_id, "UserId": user_id},
    )


async def describe(hub, ctx, user_id: str, instance_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes the specified user account. You can find the instance ID in the console (it’s the final part of the ARN). The console does not display the user IDs. Instead, list the users and note the IDs provided in the output.

    Args:
        user_id(str): The identifier of the user account.
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.user.init.describe(
                ctx, user_id=value, instance_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.user.init.describe user_id=value, instance_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="describe_user",
        op_kwargs={"UserId": user_id, "InstanceId": instance_id},
    )


async def list_all(
    hub, ctx, instance_id: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Provides summary information about the users for the specified Amazon Connect instance.

    Args:
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.
        next_token(str, optional): The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return per page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.user.init.list_all(ctx, instance_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.user.init.list_all instance_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="list_users",
        op_kwargs={
            "InstanceId": instance_id,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__sub_alias__ = ["input_", "input"]


async def create(
    hub,
    ctx,
    destinations: List = None,
    input_devices: List = None,
    input_security_groups: List = None,
    media_connect_flows: List = None,
    name: str = None,
    request_id: str = None,
    role_arn: str = None,
    sources: List = None,
    tags: Dict = None,
    type_: str = None,
    vpc: Dict = None,
) -> Dict:
    r"""
        **Autogenerated function**

        Create an input

        Args:
            destinations(List, optional): Destination settings for PUSH type inputs. Defaults to None.
            input_devices(List, optional): Settings for the devices. Defaults to None.
            input_security_groups(List, optional): A list of security groups referenced by IDs to attach to the input. Defaults to None.
            media_connect_flows(List, optional): A list of the MediaConnect Flows that you want to use in this input. You can specify as few as one
    Flow and presently, as many as two. The only requirement is when you have more than one is that each Flow is in a
    separate Availability Zone as this ensures your EML input is redundant to AZ issues.
    . Defaults to None.
            name(str, optional): Name of the input. Defaults to None.
            request_id(str, optional): Unique identifier of the request to ensure the request is handled
    exactly once in case of retries.
    . Defaults to None.
            role_arn(str, optional): The Amazon Resource Name (ARN) of the role this input assumes during and after creation. Defaults to None.
            sources(List, optional): The source URLs for a PULL-type input. Every PULL type input needs
    exactly two source URLs for redundancy.
    Only specify sources for PULL type Inputs. Leave Destinations empty.
    . Defaults to None.
            tags(Dict, optional): A collection of key-value pairs. Defaults to None.
            type_(str, optional): Placeholder documentation for InputType. Defaults to None.
            vpc(Dict, optional): Settings for a private VPC Input.
    When this property is specified, the input destination addresses will be created in a VPC rather than with public Internet addresses.
    This property requires setting the roleArn property on Input creation.
    Not compatible with the inputSecurityGroups property.
    . Defaults to None.

        Returns:
            Dict

        Examples:
            Call from code:

            .. code-block:: python

                await hub.exec.aws_auto.medialive.input_.init.create(ctx)

            Call from CLI:

            .. code-block:: bash

                $ idem exec aws_auto.medialive.input_.init.create
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="medialive",
        operation="create_input",
        op_kwargs={
            "Destinations": destinations,
            "InputDevices": input_devices,
            "InputSecurityGroups": input_security_groups,
            "MediaConnectFlows": media_connect_flows,
            "Name": name,
            "RequestId": request_id,
            "RoleArn": role_arn,
            "Sources": sources,
            "Tags": tags,
            "Type": type_,
            "Vpc": vpc,
        },
    )


async def delete(hub, ctx, input_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the input end point

    Args:
        input_id(str): Unique ID of the input.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.medialive.input_.init.delete(ctx, input_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.medialive.input_.init.delete input_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="medialive",
        operation="delete_input",
        op_kwargs={"InputId": input_id},
    )


async def describe(hub, ctx, input_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Produces details about an input

    Args:
        input_id(str): Unique ID of the input.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.medialive.input_.init.describe(ctx, input_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.medialive.input_.init.describe input_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="medialive",
        operation="describe_input",
        op_kwargs={"InputId": input_id},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Produces list of inputs that have been created

    Args:
        max_results(int, optional): Placeholder documentation for MaxResults. Defaults to None.
        next_token(str, optional): Placeholder documentation for __string. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.medialive.input_.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.medialive.input_.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="medialive",
        operation="list_inputs",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )


async def update(
    hub,
    ctx,
    input_id: str,
    destinations: List = None,
    input_devices: List = None,
    input_security_groups: List = None,
    media_connect_flows: List = None,
    name: str = None,
    role_arn: str = None,
    sources: List = None,
) -> Dict:
    r"""
        **Autogenerated function**

        Updates an input.

        Args:
            destinations(List, optional): Destination settings for PUSH type inputs. Defaults to None.
            input_devices(List, optional): Settings for the devices. Defaults to None.
            input_id(str): Unique ID of the input.
            input_security_groups(List, optional): A list of security groups referenced by IDs to attach to the input. Defaults to None.
            media_connect_flows(List, optional): A list of the MediaConnect Flow ARNs that you want to use as the source of the input. You can specify as few as one
    Flow and presently, as many as two. The only requirement is when you have more than one is that each Flow is in a
    separate Availability Zone as this ensures your EML input is redundant to AZ issues.
    . Defaults to None.
            name(str, optional): Name of the input. Defaults to None.
            role_arn(str, optional): The Amazon Resource Name (ARN) of the role this input assumes during and after creation. Defaults to None.
            sources(List, optional): The source URLs for a PULL-type input. Every PULL type input needs
    exactly two source URLs for redundancy.
    Only specify sources for PULL type Inputs. Leave Destinations empty.
    . Defaults to None.

        Returns:
            Dict

        Examples:
            Call from code:

            .. code-block:: python

                await hub.exec.aws_auto.medialive.input_.init.update(ctx, input_id=value)

            Call from CLI:

            .. code-block:: bash

                $ idem exec aws_auto.medialive.input_.init.update input_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="medialive",
        operation="update_input",
        op_kwargs={
            "Destinations": destinations,
            "InputDevices": input_devices,
            "InputId": input_id,
            "InputSecurityGroups": input_security_groups,
            "MediaConnectFlows": media_connect_flows,
            "Name": name,
            "RoleArn": role_arn,
            "Sources": sources,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def register(
    hub,
    ctx,
    client_id: str,
    user_code: str,
    product_id: str,
    amazon_id: str,
    device_serial_number: str = None,
    room_arn: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Registers an Alexa-enabled device built by an Original Equipment Manufacturer (OEM) using Alexa Voice Service (AVS).

    Args:
        client_id(str): The client ID of the OEM used for code-based linking authorization on an AVS device.
        user_code(str): The code that is obtained after your AVS device has made a POST request to LWA as a part of the Device Authorization Request component of the OAuth code-based linking specification.
        product_id(str): The product ID used to identify your AVS device during authorization.
        device_serial_number(str, optional): The key generated by the OEM that uniquely identifies a specified instance of your AVS device. Defaults to None.
        amazon_id(str): The device type ID for your AVS device generated by Amazon when the OEM creates a new product on Amazon's Developer Console.
        room_arn(str, optional): The Amazon Resource Name (ARN) of the room with which to associate your AVS device. Defaults to None.
        tags(List, optional): The tags to be added to the specified resource. Do not provide system tags. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.avs_device.register(
                ctx, client_id=value, user_code=value, product_id=value, amazon_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.avs_device.register client_id=value, user_code=value, product_id=value, amazon_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="register_avs_device",
        op_kwargs={
            "ClientId": client_id,
            "UserCode": user_code,
            "ProductId": product_id,
            "DeviceSerialNumber": device_serial_number,
            "AmazonId": amazon_id,
            "RoomArn": room_arn,
            "Tags": tags,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub,
    ctx,
    service_namespace: str,
    resource_id: str = None,
    scalable_dimension: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Provides descriptive information about the scaling activities in the specified namespace from the previous six weeks. You can filter the results using ResourceId and ScalableDimension.

    Args:
        service_namespace(str): The namespace of the AWS service that provides the resource. For a resource provided by your own application or service, use custom-resource instead.
        resource_id(str, optional): The identifier of the resource associated with the scaling activity. This string consists of the resource type and unique identifier.   ECS service - The resource type is service and the unique identifier is the cluster name and service name. Example: service/default/sample-webapp.   Spot Fleet request - The resource type is spot-fleet-request and the unique identifier is the Spot Fleet request ID. Example: spot-fleet-request/sfr-73fbd2ce-aa30-494c-8788-1cee4EXAMPLE.   EMR cluster - The resource type is instancegroup and the unique identifier is the cluster ID and instance group ID. Example: instancegroup/j-2EEZNYKUA1NTV/ig-1791Y4E1L8YI0.   AppStream 2.0 fleet - The resource type is fleet and the unique identifier is the fleet name. Example: fleet/sample-fleet.   DynamoDB table - The resource type is table and the unique identifier is the table name. Example: table/my-table.   DynamoDB global secondary index - The resource type is index and the unique identifier is the index name. Example: table/my-table/index/my-table-index.   Aurora DB cluster - The resource type is cluster and the unique identifier is the cluster name. Example: cluster:my-db-cluster.   Amazon SageMaker endpoint variant - The resource type is variant and the unique identifier is the resource ID. Example: endpoint/my-end-point/variant/KMeansClustering.   Custom resources are not supported with a resource type. This parameter must specify the OutputValue from the CloudFormation template stack used to access the resources. The unique identifier is defined by the service provider. More information is available in our GitHub repository.   Amazon Comprehend document classification endpoint - The resource type and unique identifier are specified using the endpoint ARN. Example: arn:aws:comprehend:us-west-2:123456789012:document-classifier-endpoint/EXAMPLE.   Amazon Comprehend entity recognizer endpoint - The resource type and unique identifier are specified using the endpoint ARN. Example: arn:aws:comprehend:us-west-2:123456789012:entity-recognizer-endpoint/EXAMPLE.   Lambda provisioned concurrency - The resource type is function and the unique identifier is the function name with a function version or alias name suffix that is not $LATEST. Example: function:my-function:prod or function:my-function:1.   Amazon Keyspaces table - The resource type is table and the unique identifier is the table name. Example: keyspace/mykeyspace/table/mytable.   Amazon MSK cluster - The resource type and unique identifier are specified using the cluster ARN. Example: arn:aws:kafka:us-east-1:123456789012:cluster/demo-cluster-1/6357e0b2-0e6a-4b86-a0b4-70df934c2e31-5.  . Defaults to None.
        scalable_dimension(str, optional): The scalable dimension. This string consists of the service namespace, resource type, and scaling property. If you specify a scalable dimension, you must also specify a resource ID.    ecs:service:DesiredCount - The desired task count of an ECS service.    ec2:spot-fleet-request:TargetCapacity - The target capacity of a Spot Fleet request.    elasticmapreduce:instancegroup:InstanceCount - The instance count of an EMR Instance Group.    appstream:fleet:DesiredCapacity - The desired capacity of an AppStream 2.0 fleet.    dynamodb:table:ReadCapacityUnits - The provisioned read capacity for a DynamoDB table.    dynamodb:table:WriteCapacityUnits - The provisioned write capacity for a DynamoDB table.    dynamodb:index:ReadCapacityUnits - The provisioned read capacity for a DynamoDB global secondary index.    dynamodb:index:WriteCapacityUnits - The provisioned write capacity for a DynamoDB global secondary index.    rds:cluster:ReadReplicaCount - The count of Aurora Replicas in an Aurora DB cluster. Available for Aurora MySQL-compatible edition and Aurora PostgreSQL-compatible edition.    sagemaker:variant:DesiredInstanceCount - The number of EC2 instances for an Amazon SageMaker model endpoint variant.    custom-resource:ResourceType:Property - The scalable dimension for a custom resource provided by your own application or service.    comprehend:document-classifier-endpoint:DesiredInferenceUnits - The number of inference units for an Amazon Comprehend document classification endpoint.    comprehend:entity-recognizer-endpoint:DesiredInferenceUnits - The number of inference units for an Amazon Comprehend entity recognizer endpoint.    lambda:function:ProvisionedConcurrency - The provisioned concurrency for a Lambda function.    cassandra:table:ReadCapacityUnits - The provisioned read capacity for an Amazon Keyspaces table.    cassandra:table:WriteCapacityUnits - The provisioned write capacity for an Amazon Keyspaces table.    kafka:broker-storage:VolumeSize - The provisioned volume size (in GiB) for brokers in an Amazon MSK cluster.  . Defaults to None.
        max_results(int, optional): The maximum number of scalable targets. This value can be between 1 and 50. The default value is 50. If this parameter is used, the operation returns up to MaxResults results at a time, along with a NextToken value. To get the next set of results, include the NextToken value in a subsequent call. If this parameter is not used, the operation returns up to 50 results and a NextToken value, if applicable. Defaults to None.
        next_token(str, optional): The token for the next set of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.application_autoscaling.scaling.activity.describe_all(
                ctx, service_namespace=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.application_autoscaling.scaling.activity.describe_all service_namespace=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="application-autoscaling",
        operation="describe_scaling_activities",
        op_kwargs={
            "ServiceNamespace": service_namespace,
            "ResourceId": resource_id,
            "ScalableDimension": scalable_dimension,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )
